@@ -50,7 +50,7 @@ class ControlFile(object):
     """
     """
 
-    def __init__(self,Icon,PreInst,PostInst,PreRm,PostRm,
+    def __init__(self,Icon,BugTracker,DisplayName,PreInst,PostInst,PreRm,PostRm,
                  long_description = "",
                  Description = "",
                  **kwargs
@@ -63,7 +63,8 @@ class ControlFile(object):
         self.description = Description
         self.long_description = long_description
         self.icon = Icon
-        
+        self.bugtracker = BugTracker
+        self.displayname = DisplayName
         self.preinst=PreInst
         self.postinst=PostInst
         self.prerm=PreRm
@@ -87,7 +88,10 @@ class ControlFile(object):
         if self.icon:
             #self.icon=self.icon.replace("\n","\n ")
             content.append("Maemo-Icon-26: \n %s" % self.icon)
-            
+        if self.bugtracker:
+            content.append("XSBC-Bugtracker: \n %s" % self.bugtracker)
+        if self.displayname:
+            content.append("XB-Maemo-Display-Name: \n %s" % self.displayname)
             #print self.icon
 
         print "\n".join(content) + "\n"
@@ -236,18 +240,21 @@ class MaemoPackage(object):
         files=[]
         CURRENT = os.path.dirname(sys.argv[0])
         for path in paths:
-#            print CURRENT,os.path.dirname(self.__files[path][0][)
-#            tarinfo = tarOutput.gettarinfo(os.path.join(CURRENT,os.path.dirname(self.__files[path][0])), path)
-#            tarinfo.uid = UID_ROOT
-#            tarinfo.gid = GID_ROOT
-#            tarinfo.uname = ""
-#            tarinfo.gname = ""                    
-#            tarOutput.addfile(tarinfo)            
+            print CURRENT,path
+            #tarinfo = tarOutput.gettarinfo(os.path.join(CURRENT,os.path.dirname(self.__files[path][0])), path)
+            #tarinfo.uid = UID_ROOT
+            #tarinfo.gid = GID_ROOT
+            #tarinfo.uname = ""
+            #tarinfo.gname = ""                    
+            #tarOutput.addfile(tarinfo)
+            
+               
             
             for pfile,nfile in self.__files[path]:
-                #~ rfile=os.path.normpath( os.path.join(path,nfile) )
-                rfile=os.path.join(path,nfile)
-                if nfile==pfile:
+                rfile=os.path.normpath( os.path.join(path,nfile) )
+                print pfile, nfile, rfile, path
+                #rfile=os.path.join(path,nfile)
+                if os.path.dirname(rfile)==path:
 #                    tarinfo = tarOutput.gettarinfo(os.path.join(os.path.dirname(sys.argv[0]),rfile), os.path.dirname(os.path.join(os.path.dirname(sys.argv[0]),rfile)))
 #                    tarinfo = tarfile.TarInfo(name=os.path.join(path,pfile))
 #                    tarinfo.name = os.path.join(path,pfile)
